@@ -9,9 +9,9 @@ from . import usage, version
 from .retriever import retrieve_model, retrieve_model_from_file, retrieve_raw
 
 
-def main():
+def _arg_parser():
     """
-    Main entry point.
+    Command line argument parsing.
     """
     parser = argparse.ArgumentParser(
         description=usage[0],
@@ -19,29 +19,27 @@ def main():
         formatter_class=argparse.RawDescriptionHelpFormatter,
     )
 
-    parser = argparse.ArgumentParser()
-
     parser.add_argument("-v", action="version", version=version(parser.prog))
 
-    parser.add_argument("--reference_id", help="the reference id")
+    parser.add_argument("--id", help="the reference id")
 
     parser.add_argument(
-        "--sizeoff", help="do not consider file size", action="store_true"
-    )
-
-    parser.add_argument("--parse", help="parse reference content", action="store_true")
-
-    parser.add_argument("--indent", help="indentation spaces", default=None)
-
-    parser.add_argument(
-        "--source", help="retrieval source", choices=["ncbi", "ensembl", "lrg"]
+        "-s", "--source", help="retrieval source", choices=["ncbi", "ensembl", "lrg"]
     )
 
     parser.add_argument(
-        "--type", help="reference type", choices=["gff3", "genbank", "json", "fasta"]
+        "-t",
+        "--type",
+        help="reference type",
+        choices=["gff3", "genbank", "json", "fasta"],
     )
 
     parser.add_argument(
+        "-p", "--parse", help="parse reference content", action="store_true"
+    )
+
+    parser.add_argument(
+        "-m",
         "--model_type",
         help="include the complete model or parts of it",
         choices=["all", "sequence", "annotations"],
@@ -50,17 +48,21 @@ def main():
 
     parser.add_argument("--timeout", help="timeout", type=int)
 
-    parser.add_argument("-c", "--configuration", help="configuration file path")
+    parser.add_argument("--indent", help="indentation spaces", default=None)
 
-    subparsers = parser.add_subparsers(
-        help="parse files to get the model", dest="from_file"
+    parser.add_argument(
+        "--sizeoff", help="do not consider file size", action="store_true"
     )
 
-    parser_from_file = subparsers.add_parser("from_file")
+    parser.add_argument("-c", "--configuration", help="configuration file path")
+
+    subparsers = parser.add_subparsers(dest="from_file")
+
+    parser_from_file = subparsers.add_parser("from_file", help="parse files to get the model")
 
     parser_from_file.add_argument(
         "--paths",
-        help="either gff3 and fasta paths or just one for lrg",
+        help="both gff3 and fasta paths or just an lrg",
         nargs="+",
     )
     parser_from_file.add_argument(
@@ -69,8 +71,19 @@ def main():
         action="store_true",
         default=False,
     )
+    return parser
 
-    args = parser.parse_args()
+
+def main():
+    """
+    Main entry point.
+    """
+    parser = _arg_parser()
+
+    try:
+        args = parser.parse_args()
+    except IOError as error:
+        parser.error(error)
 
     if args.indent:
         args.indent = int(args.indent)
@@ -80,7 +93,7 @@ def main():
         print(json.dumps(output, indent=args.indent))
     elif args.parse:
         output = retrieve_model(
-            reference_id=args.reference_id,
+            reference_id=args.id,
             reference_source=args.source,
             reference_type=args.type,
             model_type=args.model_type,
@@ -90,7 +103,7 @@ def main():
         print(json.dumps(output, indent=args.indent))
     else:
         output = retrieve_raw(
-            reference_id=args.reference_id,
+            reference_id=args.id,
             reference_source=args.source,
             reference_type=args.type,
             size_off=args.sizeoff,
